/*-
 *  Copyright 2022 Beuth Hochschule für Technik Berlin, Hochschule für Technik Stuttgart
 * 
 *  This file is part of CityDoctor2.
 *
 *  CityDoctor2 is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  CityDoctor2 is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with CityDoctor2.  If not, see <https://www.gnu.org/licenses/>.
 */
package de.hft.stuttgart.citydoctor2.gui.tree;

import java.util.List;

import de.hft.stuttgart.citydoctor2.datastructure.BridgeConstructiveElement;
import de.hft.stuttgart.citydoctor2.gui.CheckStatus;
import de.hft.stuttgart.citydoctor2.gui.Renderer;

public class AllBridgeConstructiveElementsNode extends Renderable {
	
	private List<BridgeConstructiveElement> constructiveElements;
	
	public AllBridgeConstructiveElementsNode(List<BridgeConstructiveElement> constructiveElements) {
		this.constructiveElements = constructiveElements;
	}
	
	@Override
	public String getText() {
		return "Constructive Elements";
	}

	@Override
	public void visit(Renderer renderer) {
		renderer.clearCurrentRender();
	}

	@Override
	public void refreshTextColor() {
		boolean isValidated = false;
		for (BridgeConstructiveElement bce : constructiveElements) {
			if (bce.isValidated()) {
				isValidated = true;
			}
			if (bce.containsAnyError()) {
				setStatus(CheckStatus.ERROR);
				return;
			}
		}
		if (isValidated) {
			setStatus(CheckStatus.OK);
		} else {
			setStatus(CheckStatus.NOT_CHECKED);
		}
	}

}
